( cd usr/i486-linuxaout/include ; rm -rf asm )
( cd usr/i486-linuxaout/include ; ln -sf /usr/src/linux/include/asm asm )
( cd usr/i486-linuxaout/include ; rm -rf linux )
( cd usr/i486-linuxaout/include ; ln -sf /usr/src/linux/include/linux linux )
( cd lib ; rm -rf libc.so.4 )
( cd lib ; ln -sf libc.so.4.7.6 libc.so.4 )
( cd lib ; rm -rf libm.so.4 )
( cd lib ; ln -sf libm.so.4.6.27 libm.so.4 )
( cd lib ; rm -rf libcurses.so.0 )
( cd lib ; ln -sf libcurses.so.0.1.2 libcurses.so.0 )
( cd usr/i486-linuxaout/lib ; rm -rf libdbm.a )
( cd usr/i486-linuxaout/lib ; ln -sf libgdbm.a libdbm.a )
( cd usr/i486-linuxaout/lib ; rm -rf libdbm.sa )
( cd usr/i486-linuxaout/lib ; ln -sf libgdbm.sa libdbm.sa )
( cd usr/i486-linuxaout/lib ; rm -rf libdb.so.1 )
( cd usr/i486-linuxaout/lib ; ln -sf libdb.so.1.85.1 libdb.so.1 )
